@@ -199,7 +199,7 @@ auth_gsasl_capa_init (int disable)
 		    MU_WRDSF_DELIM|MU_WRDSF_SQUEEZE_DELIMS|
 		    MU_WRDSF_NOVAR|MU_WRDSF_NOCMD))
     {
-      mu_error (_("cannot split line `%s': %s"), listmech,
+      mu_error (_("cannot split line %s: %s"), mu_quotename (listmech),
 		mu_wordsplit_strerror (&ws));
     }
   else
