@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2019 Free Software Foundation, Inc.
+   Copyright (C) 1999-2025 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -16,6 +16,7 @@
 
 #include "imap4d.h"
 #include <mailutils/property.h>
+#include <mailutils/datetime.h>
 
 mu_stream_t iostream;
 
@@ -28,7 +29,7 @@ log_cipher (mu_stream_t stream)
   if (rc)
     {
       mu_diag_output (MU_DIAG_INFO, _("TLS established"));
-      mu_diag_output (MU_DIAG_ERROR, _("can't get TLS details: %s"),
+      mu_diag_output (MU_DIAG_ERROR, _("cannot get TLS details: %s"),
 		      mu_strerror (rc));
     }
   else
@@ -52,51 +53,54 @@ void
 io_setio (int ifd, int ofd, struct mu_tls_config *tls_conf)
 {
   mu_stream_t str, istream, ostream;
+  int rc;
   
   if (ifd == -1)
     imap4d_bye (ERR_NO_IFILE);
   if (ofd == -1)
     imap4d_bye (ERR_NO_OFILE);
 
-  if (mu_stdio_stream_create (&istream, ifd, MU_STREAM_READ))
-    imap4d_bye (ERR_STREAM_CREATE);
-  mu_stream_set_buffer (istream, mu_buffer_line, 0);
-  
-  if (mu_stdio_stream_create (&ostream, ofd, MU_STREAM_WRITE))
-    imap4d_bye (ERR_STREAM_CREATE);
-  mu_stream_set_buffer (ostream, mu_buffer_line, 0);
-  
-  /* Combine the two streams into an I/O one. */
   if (tls_conf)
     {
-      int rc = mu_tls_stream_create (&str, istream, ostream,
-				     tls_conf,
-				     MU_TLS_SERVER,
-				     0);
+      rc = mu_tlsfd_stream_create (&str, ifd, ofd, tls_conf, MU_TLS_SERVER);
       if (rc)
 	{
-	  mu_stream_unref (istream);
-	  mu_stream_unref (ostream);
 	  mu_error (_("failed to create TLS stream: %s"), mu_strerror (rc));
 	  imap4d_bye (ERR_STREAM_CREATE);
 	}
       log_cipher (str);
     }
-  else if (mu_iostream_create (&str, istream, ostream))
-    imap4d_bye (ERR_STREAM_CREATE);
+  else
+    {
+      if (mu_stdio_stream_create (&istream, ifd, MU_STREAM_READ))
+	imap4d_bye (ERR_STREAM_CREATE);
+      mu_stream_set_buffer (istream, mu_buffer_line, 0);
+  
+      if (mu_stdio_stream_create (&ostream, ofd, MU_STREAM_WRITE))
+	imap4d_bye (ERR_STREAM_CREATE);
+      mu_stream_set_buffer (ostream, mu_buffer_line, 0);
+  
+      /* Combine the two streams into an I/O one. */
+      if (mu_iostream_create (&str, istream, ostream))
+	imap4d_bye (ERR_STREAM_CREATE);
 
+      mu_stream_unref (istream);
+      mu_stream_unref (ostream);
+    }
+  
   /* Convert all writes to CRLF form.
      There is no need to convert reads, as the code ignores extra \r anyway.
   */
-  if (mu_filter_create (&iostream, str, "CRLF", MU_FILTER_ENCODE,
-			MU_STREAM_WRITE | MU_STREAM_RDTHRU))
+  rc = mu_filter_create (&iostream, str, "CRLF", MU_FILTER_ENCODE,
+			 MU_STREAM_WRITE | MU_STREAM_RDTHRU);
+  mu_stream_unref (str);
+  if (rc)
     imap4d_bye (ERR_STREAM_CREATE);
   /* Change buffering scheme: filter streams are fully buffered by default. */
   mu_stream_set_buffer (iostream, mu_buffer_line, 0);
   
   if (imap4d_transcript)
     {
-      int rc;
       mu_stream_t dstr, xstr;
       
       rc = mu_dbgstream_create (&dstr, MU_DIAG_DEBUG);
@@ -122,45 +126,18 @@ io_setio (int ifd, int ofd, struct mu_tls_config *tls_conf)
 int
 imap4d_init_tls_server (struct mu_tls_config *tls_conf)
 {
-  mu_stream_t tlsstream, stream[2];
   int rc;
-
-  rc = mu_stream_ioctl (iostream, MU_IOCTL_SUBSTREAM, MU_IOCTL_OP_GET, stream);
-  if (rc)
-    {
-      mu_error (_("%s failed: %s"), "MU_IOCTL_GET_STREAM",
-		mu_stream_strerror (iostream, rc));
-      return 1;
-    }
   
-  rc = mu_tls_stream_create (&tlsstream, stream[0], stream[1],
-			     tls_conf,
-			     MU_TLS_SERVER,
-			     0);
-  mu_stream_unref (stream[0]);
-  mu_stream_unref (stream[1]);
-  if (rc)
+  rc = mu_starttls (&iostream, tls_conf, MU_TLS_SERVER);
+  if (rc == 0)
+    log_cipher (iostream);
+  else
     {
-      mu_diag_output (MU_DIAG_ERROR, _("cannot open TLS stream: %s"),
-		      mu_strerror (rc));
-      return 1;
+      mu_diag_funcall (MU_DIAG_ERROR, "mu_starttls", NULL, rc);
+      if (rc == MU_ERR_TRANSPORT_SET)
+	imap4d_bye (ERR_NO_IFILE);
     }
-
-  log_cipher (tlsstream);
-
-  stream[0] = stream[1] = tlsstream;
-
-  rc = mu_stream_ioctl (iostream, MU_IOCTL_SUBSTREAM, MU_IOCTL_OP_SET, stream);
-  if (rc)
-    {
-      mu_error (_("%s failed: %s"), "MU_IOCTL_SET_STREAM",
-		mu_stream_strerror (iostream, rc));
-      imap4d_bye (ERR_STREAM_CREATE);
-    }
-  mu_stream_unref (stream[0]);
-  mu_stream_unref (stream[1]);
-
-  return 0;
+  return rc;
 }
 
 /* Status Code to String.  */
@@ -296,10 +273,7 @@ io_untagged_response (int rc, const char *format, ...)
 	   during initialization. */
 	return 0;
       mu_diag_output (MU_DIAG_ERROR,
-		      /* TANSLATORS: %s is replaced with the untagged response
-			 name, followed by a space character. */
-		      _("iostream is NULL while trying to send the %suntagged response"),
-		      sc2string (rc));
+		      _("iostream is NULL while trying to send untagged response"));
       exit (EX_SOFTWARE);
     }
   
@@ -373,29 +347,6 @@ io_stream_completion_response (mu_stream_t str,
   return status;
 }
 
-/* Wait TIMEOUT seconds for data on the input stream.
-   Returns 0   if no data available
-           1   if some data is available
-	   -1  an error occurred */
-int
-io_wait_input (int timeout)
-{
-  int wflags = MU_STREAM_READY_RD;
-  struct timeval tv;
-  int status;
-  
-  tv.tv_sec = timeout;
-  tv.tv_usec = 0;
-  status = mu_stream_wait (iostream, &wflags, &tv);
-  if (status)
-    {
-      mu_diag_output (MU_DIAG_ERROR, _("cannot poll input stream: %s"),
-		      mu_strerror(status));
-      return -1;
-    }
-  return wflags & MU_STREAM_READY_RD;
-}
-
 void
 io_flush ()
 {
@@ -406,7 +357,19 @@ void
 io_getline (char **pbuf, size_t *psize, size_t *pnbytes)
 {
   size_t len;
-  int rc = mu_stream_getline (iostream, pbuf, psize, &len);
+  int rc;
+  struct timeval tv, *to;
+
+  if (idle_timeout)
+    {
+      tv.tv_sec = idle_timeout;
+      tv.tv_usec = 0;
+      to = &tv;
+    }
+  else
+    to = NULL;
+
+  rc = mu_stream_timed_getline (iostream, pbuf, psize, to, &len);
   if (rc == 0)
     {
       char *s = *pbuf;
@@ -420,6 +383,8 @@ io_getline (char **pbuf, size_t *psize, size_t *pnbytes)
       if (pnbytes)
 	*pnbytes = len;
     }
+  else if (rc == MU_ERR_TIMEOUT)
+    imap4d_bye (ERR_TIMEOUT);
   else
     {
       mu_error (_("read error: %s"), mu_strerror (rc));
@@ -624,20 +589,30 @@ imap4d_tokbuf_tokenize (struct imap4d_tokbuf *tok, size_t off)
 static void
 check_input_err (int rc, size_t sz)
 {
-  if (rc)
+  switch (rc)
     {
-      const char *p = mu_stream_strerror (iostream, rc);
-      if (!p)
-	p = mu_strerror (rc);
+    case 0:
+      if (sz == 0)
+	{
+	  mu_diag_output (MU_DIAG_INFO, _("unexpected eof on input"));
+	  imap4d_bye (ERR_NO_IFILE);
+	}
+      break;
       
-      mu_diag_output (MU_DIAG_INFO,
-		      _("error reading from input file: %s"), p);
-      imap4d_bye (ERR_NO_IFILE);
-    }
-  else if (sz == 0)
-    {
-      mu_diag_output (MU_DIAG_INFO, _("unexpected eof on input"));
-      imap4d_bye (ERR_NO_IFILE);
+    case MU_ERR_TIMEOUT:
+      imap4d_bye (ERR_TIMEOUT);
+      break;
+
+    default:
+      {
+	const char *p = mu_stream_strerror (iostream, rc);
+	if (!p)
+	  p = mu_strerror (rc);
+
+	mu_diag_output (MU_DIAG_INFO,
+			_("error reading from input stream: %s"), p);
+	imap4d_bye (ERR_NO_IFILE);
+      }
     }
 }
 
@@ -646,13 +621,37 @@ imap4d_tokbuf_getline (struct imap4d_tokbuf *tok)
 {
   char buffer[512];
   size_t level = tok->level;
+  struct timeval tv, *to, stop_time;
+
+  if (idle_timeout)
+    {
+      gettimeofday (&stop_time, NULL);
+      stop_time.tv_sec += idle_timeout;
+      to = &tv;
+    }
+  else
+    to = NULL;
 
   do
     {
       size_t len;
       int rc;
+
+      if (to)
+	{
+	  struct timeval d;
+
+	  gettimeofday (&d, NULL);
+	  if (mu_timeval_cmp (&d, &stop_time) >= 0)
+	    {
+	      rc = MU_ERR_TIMEOUT;
+	      break;
+	    }
+	  *to = mu_timeval_sub (&stop_time, &d);
+	}
       
-      rc = mu_stream_readline (iostream, buffer, sizeof (buffer), &len);
+      rc = mu_stream_timed_readline (iostream, buffer, sizeof (buffer),
+				     to, &len);
       check_input_err (rc, len);
       imap4d_tokbuf_expand (tok, len);
       
@@ -688,7 +687,6 @@ imap4d_readline (struct imap4d_tokbuf *tok)
 	  char *sp = NULL;
 	  char *buf;
 	  size_t len;
-	  int xlev = set_xscript_level (MU_XSCRIPT_PAYLOAD);
 	  
 	  number = strtoul (last_arg + 1, &sp, 10);
 	  /* Client can ask for non-synchronised literal,
@@ -697,6 +695,7 @@ imap4d_readline (struct imap4d_tokbuf *tok)
 	    io_sendf ("+ GO AHEAD\n");
 	  else if (*sp != '+')
 	    break;
+	  xscript_declare_client_payload (number);
 	  imap4d_tokbuf_expand (tok, number + 1);
 	  off = tok->level;
 	  buf = tok->buffer + off;
@@ -715,7 +714,6 @@ imap4d_readline (struct imap4d_tokbuf *tok)
 	  tok->level += len;
 	  tok->buffer[tok->level++] = 0;
 	  tok->argp[tok->argc - 1] = off;
-	  set_xscript_level (xlev);
 	}
       else
 	break;
