@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2022 Free Software Foundation, Inc.
+   Copyright (C) 1999-2025 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -107,7 +107,7 @@ namespace_init (void)
 	    }
 	  else if (rc)
 	    {
-	      mu_error (_("%s: can't install prefix: %s"),
+	      mu_error (_("%s: cannot install prefix: %s"),
 			pfx->prefix, mu_strerror (rc));
 	      exit (EX_CONFIG);
 	    }
@@ -138,7 +138,7 @@ namespace_init (void)
       rc = mu_assoc_install (prefixes, pfx->prefix, pfx);
       if (rc)
 	{
-	  mu_error (_("%s: can't install prefix: %s"),
+	  mu_error (_("%s: cannot install prefix: %s"),
 		    pfx->prefix, mu_strerror (rc));
 	  exit (EX_CONFIG);
 	}
@@ -314,23 +314,26 @@ namespace_translate_name (char const *name,
 	}
 
       rc = mu_str_expand (&dir, res, assoc);
-      free (res);
       mu_assoc_destroy (&assoc);
       if (rc)
 	{
 	  if (rc == MU_ERR_FAILURE)
 	    {
-	      mu_error (_("cannot expand line `%s': %s"), res, dir);
+	      mu_error (_("cannot expand line %s: %s"), mu_quotename (res),
+			dir);
 	      free (dir);
 	    }
 	  else
 	    {
-	      mu_error (_("cannot expand line `%s': %s"), res,
+	      mu_error (_("cannot expand line %s: %s"), mu_quotename (res),
 			mu_strerror (rc));
 	    }
+	  free (res);
 	  imap4d_bye (ERR_NO_MEM);
 	}
-      
+      else
+	free (res);
+
       res = dir;
       trim_delim (res, '/');
     }
