@@ -1,6 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2001, 2007, 2010-2012, 2014-2016 Free Software
-   Foundation, Inc.
+   Copyright (C) 1999-2025 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -31,10 +30,10 @@ extern "C" {
 
 struct _mu_body
 {
-  void *owner;
-  mu_stream_t stream;
-  mu_stream_t rawstream;
-  mu_stream_t fstream;
+  int ref_count;           /* Reference counter */
+  void *owner;             /* Owner object pointer */
+  mu_stream_t data_stream; /* Body content stream */
+  mu_stream_t temp_stream; /* RW temporary stream (for writing to the body) */
   int flags;
 
   int (*_size)  (mu_body_t, size_t*);
