@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2024 Free Software Foundation, Inc.
+   Copyright (C) 1999-2025 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -30,6 +30,7 @@
 #include <mailutils/registrar.h>
 #include <mailutils/nls.h>
 #include <mailutils/cfg.h>
+#include <mailutils/cstr.h>
 #include "muaux.h"
 
 /* This file implements mandatory locking for pop3d and imap4d.  Mandatory
@@ -237,8 +238,9 @@ void
 manlock_cfg_init ()
 {
   struct mu_cfg_section *section;
-  mu_create_canned_section ("mandatory-locking", &section);
-  mu_cfg_section_add_params (section, manlock_param);
+  mu_create_canned_section_ext ("mandatory-locking", DEFAULT_TEXT_DOMAIN,
+				&section);
+  mu_cfg_section_add_params_ext (section, manlock_param, DEFAULT_TEXT_DOMAIN);
 }
 
 int
@@ -258,8 +260,9 @@ manlock_lock (mu_mailbox_t mbox)
   mu_locker_modify (lock, &hints);
   if ((status = mu_locker_lock (lock)))
     {
-      mu_diag_output (MU_DIAG_NOTICE, _("locking mailbox `%s' failed: %s"),
-	      name ? name : "?", mu_strerror(status));
+      mu_diag_output (MU_DIAG_NOTICE,
+		      _("locking mailbox %s failed: %s"),
+		      name ? mu_quotename (name) : "?", mu_strerror (status));
       return status;
     }
   return 0;
