@@ -1,5 +1,5 @@
 /* cfg_format.c -- convert configuration parse tree to human-readable format.
-   Copyright (C) 2007-2019 Free Software Foundation, Inc.
+   Copyright (C) 2007-2025 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -350,26 +350,30 @@ mu_cfg_format_docstring (mu_stream_t stream, const char *docstring, int level)
 }
 
 static void
-format_param (mu_stream_t stream, struct mu_cfg_param *param, int level)
+format_param (mu_stream_t stream, char const *domain,
+	      struct mu_cfg_param *param, int level)
 {
   if (param->docstring)
-    mu_cfg_format_docstring (stream, gettext (param->docstring), level);
+    mu_cfg_format_docstring (stream, dgettext (domain, param->docstring),
+			     level);
   format_level (stream, level);
   if (param->argname && strchr (param->argname, ':'))
     mu_stream_printf (stream, "%s <%s>;\n",
 		      param->ident,
-		      gettext (param->argname));
+		      dgettext (domain, param->argname));
   else if (MU_CFG_IS_LIST (param->type))
-    mu_stream_printf (stream, "%s <%s: list of %s>;\n",
+    mu_stream_printf (stream, "%s <%s: (%s, ...)>;\n",
 		      param->ident,
-		      gettext (param->argname ?
-			       param->argname : N_("arg")),
-	gettext (mu_c_type_string (MU_CFG_TYPE (param->type))));
+		      param->argname
+		        ? dgettext (domain, param->argname)
+		        : gettext ("arg"),
+		      gettext (mu_c_type_string (MU_CFG_TYPE (param->type))));
   else
     mu_stream_printf (stream, "%s <%s: %s>;\n",
 		      param->ident,
-		      gettext (param->argname ?
-			       param->argname : N_("arg")),
+		      param->argname
+		        ? dgettext (domain, param->argname)
+		        : gettext ("arg"),
 		      gettext (mu_c_type_string (param->type)));
 }
 
@@ -386,11 +390,13 @@ _f_helper (void *item, void *data)
 }
   
 static void
-format_section (mu_stream_t stream, struct mu_cfg_section *sect, int level)
+format_section (mu_stream_t stream, char const *domain,
+		struct mu_cfg_section *sect, int level)
 {
   struct tree_print c;
   if (sect->docstring)
-    mu_cfg_format_docstring (stream, gettext (sect->docstring), level);
+    mu_cfg_format_docstring (stream, dgettext (domain, sect->docstring),
+			     level);
   format_level (stream, level);
   if (sect->ident)
     {
@@ -421,11 +427,11 @@ format_container (mu_stream_t stream, struct mu_cfg_cont *cont, int level)
   switch (cont->type)
     {
     case mu_cfg_cont_section:
-      format_section (stream, &cont->v.section, level);
+      format_section (stream, cont->domain, &cont->v.section, level);
       break;
 
     case mu_cfg_cont_param:
-      format_param (stream, &cont->v.param, level);
+      format_param (stream, cont->domain, &cont->v.param, level);
       break;
     }
 }
