@@ -32,6 +32,7 @@
 #include <mailutils/mu_auth.h>
 #include <mailutils/url.h>
 #include <mailutils/kwd.h>
+#include <mailutils/cstr.h>
 
 /* *************************************************************************
  * Logging section
@@ -41,7 +42,8 @@ cli_log_facility (struct mu_parseopt *po, struct mu_option *opt,
 		  char const *arg)
 {
   if (mu_string_to_syslog_facility (arg, &mu_log_facility))
-    mu_parseopt_error (po, _("unknown syslog facility `%s'"), arg);
+    mu_parseopt_error (po, _("unknown syslog facility: %s"),
+		       mu_quotename (arg));
 }
 
 static int
@@ -52,7 +54,8 @@ cb_facility (void *data, mu_config_value_t *val)
 
   if (mu_string_to_syslog_facility (val->v.string, &mu_log_facility))
     {
-      mu_error (_("unknown syslog facility `%s'"), val->v.string);
+      mu_error (_("unknown syslog facility: %s"),
+		mu_quotename (val->v.string));
       return 1;
     }
    return 0;
@@ -67,7 +70,7 @@ cb_severity (void *data, mu_config_value_t *val)
     return 1;
   if (mu_severity_from_string (val->v.string, &n))
     {
-      mu_error (_("unknown severity `%s'"), val->v.string);
+      mu_error (_("unknown severity: %s"), mu_quotename (val->v.string));
       return 1;
     }
   mu_log_severity_threshold = n;
@@ -100,7 +103,7 @@ static struct mu_cfg_param logging_cfg[] = {
 static struct mu_option logging_option[] = {
   { "log-facility", 0, N_("FACILITY"), MU_OPTION_DEFAULT,
     N_("output logs to syslog FACILITY"),
-    mu_c_int, &mu_log_facility, cli_log_facility },
+    mu_c_int, &mu_log_facility, cli_log_facility, NULL, DEFAULT_TEXT_DOMAIN },
   MU_OPTION_END
 };
 
@@ -120,14 +123,14 @@ cli_mailer (struct mu_parseopt *po, struct mu_option *opt, char const *arg)
 {
   int rc = mu_mailer_set_url_default (arg);
   if (rc != 0)
-    mu_parseopt_error (po, _("invalid mailer URL `%s': %s"),
-		       arg, mu_strerror (rc));
+    mu_parseopt_error (po, _("invalid mailer URL %s: %s"),
+		       mu_quotename (arg), mu_strerror (rc));
 }
 
 static struct mu_option mailer_option[] = {
   { "mailer", 'M', N_("MAILER"), MU_OPTION_DEFAULT,
     N_("use specified URL as the default mailer"),
-    mu_c_string, NULL, cli_mailer },
+    mu_c_string, NULL, cli_mailer, NULL, DEFAULT_TEXT_DOMAIN },
   MU_OPTION_END
 };
 
@@ -165,13 +168,13 @@ cli_debug_level (struct mu_parseopt *po, struct mu_option *opt,
 }
 
 static struct mu_option debug_option[] = {
-  MU_OPTION_GROUP (N_("Global debugging settings")),
+  MU_OPTION_GROUP_EXT (N_("Global debugging settings"), DEFAULT_TEXT_DOMAIN),
   { "debug-level", 0, N_("LEVEL"), MU_OPTION_DEFAULT,
     N_("set Mailutils debugging level"),
-    mu_c_string, NULL, cli_debug_level },
+    mu_c_string, NULL, cli_debug_level, NULL, DEFAULT_TEXT_DOMAIN },
   { "debug-line-info", 0, NULL,    MU_OPTION_DEFAULT,
     N_("show source info with debugging messages"),
-    mu_c_bool, &mu_debug_line_info },
+    mu_c_bool, &mu_debug_line_info, NULL, NULL, DEFAULT_TEXT_DOMAIN },
   MU_OPTION_END
 };
 
@@ -209,8 +212,8 @@ cb_mail_spool (void *data, mu_config_value_t *val)
     return 1;
   rc = mu_set_mail_directory (val->v.string);
   if (rc)
-    mu_error (_("cannot set mail directory name to `%s': %s"),
-	      val->v.string, mu_strerror (rc));
+    mu_error (_("cannot set mail directory name to %s: %s"),
+	      mu_quotename (val->v.string), mu_strerror (rc));
   return rc;
 }
 
@@ -223,8 +226,8 @@ cb_mailbox_pattern (void *data, mu_config_value_t *val)
 
   rc = mu_set_mailbox_pattern (val->v.string);
   if (rc)
-    mu_error (_("cannot set mailbox pattern to `%s': %s"),
-	      val->v.string, mu_strerror (rc));
+    mu_error (_("cannot set mailbox pattern to %s: %s"),
+	      mu_quotename (val->v.string), mu_strerror (rc));
   return rc;
 }
 
@@ -325,7 +328,7 @@ cb_locker_flags (void *data, mu_config_value_t *val)
       char const *kw;
       if (mu_kwd_xlat_tok (flag_tab, *s, &kw))
 	{
-	  mu_error (_("invalid lock flag `%c'"), *s);
+	  mu_error (_("invalid lock flag '%c'"), *s);
 	}
       else if (*s == 'P')
 	{
@@ -537,8 +540,8 @@ cb_email_addr (void *data, mu_config_value_t *val)
 
   rc = mu_set_user_email (val->v.string);
   if (rc)
-    mu_error (_("invalid email address `%s': %s"),
-	      val->v.string, mu_strerror (rc));
+    mu_error (_("invalid email address %s: %s"),
+	      mu_quotename (val->v.string), mu_strerror (rc));
   return 0;
 }
 
@@ -552,8 +555,8 @@ cb_email_domain (void *data, mu_config_value_t *val)
 
   rc = mu_set_user_email_domain (val->v.string);
   if (rc)
-    mu_error (_("invalid email domain `%s': %s"),
-	      val->v.string, mu_strerror (rc));
+    mu_error (_("invalid email domain %s: %s"),
+	      mu_quotename (val->v.string), mu_strerror (rc));
   return 0;
 }
 
@@ -640,12 +643,12 @@ static struct mu_cfg_param mu_auth_param[] = {
     /* FIXME: The description is incomplete. MU-list is also allowed as
        argument */
     N_("Set a list of modules for authentication. Modlist is a "
-       "colon-separated list of module names or a word `clear' to "
+       "colon-separated list of module names or a word 'clear' to "
        "clear the previously set up values."),
     N_("modlist") },
   { "authorization", mu_cfg_callback, NULL, 0, cb_authorization,
     N_("Set a list of modules for authorization. Modlist is a "
-       "colon-separated list of module names or a word `clear' to "
+       "colon-separated list of module names or a word 'clear' to "
        "clear the previously set up values."),
     N_("modlist") },
   { NULL }
@@ -728,14 +731,16 @@ static struct mu_cfg_param mu_homedir_param[] = {
  * ************************************************************************* */
 struct mu_cli_capa mu_cli_std_capa[] = {
   { "mailutils" }, /* Dummy */
-  { "logging", logging_option, logging_cfg, NULL, logging_commit },
-  { "mailer",  mailer_option, mailer_cfg, NULL, NULL },
-  { "debug", debug_option, debug_cfg, NULL, NULL },
-  { "mailbox", NULL, mailbox_cfg, NULL, NULL },
-  { "locking", NULL, locking_cfg, NULL, NULL },
-  { "address", NULL, address_cfg, NULL, NULL },
-  { "auth",    NULL, mu_auth_param, mu_auth_section_parser },
-  { "homedir", NULL, mu_homedir_param, NULL },
+  { "logging", logging_option, logging_cfg, NULL, logging_commit,
+    DEFAULT_TEXT_DOMAIN },
+  { "mailer",  mailer_option, mailer_cfg, NULL, NULL, DEFAULT_TEXT_DOMAIN },
+  { "debug", debug_option, debug_cfg, NULL, NULL, DEFAULT_TEXT_DOMAIN },
+  { "mailbox", NULL, mailbox_cfg, NULL, NULL, DEFAULT_TEXT_DOMAIN },
+  { "locking", NULL, locking_cfg, NULL, NULL, DEFAULT_TEXT_DOMAIN },
+  { "address", NULL, address_cfg, NULL, NULL, DEFAULT_TEXT_DOMAIN },
+  { "auth",    NULL, mu_auth_param, mu_auth_section_parser, NULL,
+    DEFAULT_TEXT_DOMAIN },
+  { "homedir", NULL, mu_homedir_param, NULL, NULL, DEFAULT_TEXT_DOMAIN },
   { NULL }
 };
 
