@@ -1436,7 +1436,7 @@ yyreduce:
 	     if (count != 1)
 	       {
 		 yyerror (&(yylsp[-1]), pctl, yyscanner,
-			  "%s", _("priority takes single numberic argument"));
+			  "%s", _("priority takes a single numeric argument"));
 		 YYERROR;
 	       }
 	     mu_list_head ((yyvsp[-1].list), (void**) &arg);
@@ -1871,12 +1871,12 @@ make_functional_node (mu_mimetypes_t mth,
 
   if (count < i)
     {
-      yyerror (loc, NULL, NULL, _("too few arguments in call to `%s'"), ident);
+      yyerror (loc, NULL, NULL, _("too few arguments in call to '%s'"), ident);
       return NULL;
     }
   else if (count > i)
     {
-      yyerror (loc, NULL, NULL, _("too many arguments in call to `%s'"), ident);
+      yyerror (loc, NULL, NULL, _("too many arguments in call to '%s'"), ident);
       return NULL;
     }
 
@@ -1941,12 +1941,12 @@ make_functional_node (mu_mimetypes_t mth,
   node->v.function.builtin = p;
   node->v.function.args = args;
   return node;
-  
+
  err:
   {
     yyerror (loc, NULL, NULL,
-	     _("argument %lu has wrong type in call to `%s'"),
-	     (unsigned long) i, ident); 
+	     _("argument %lu has wrong type in call to '%s'"),
+	     (unsigned long) i, mu_quotename (ident));
     return NULL;
   }
 }
