@@ -84,15 +84,9 @@ exp_getvar (char **ret, const char *vptr, size_t vlen, void *data)
 static int
 exp_localpart (int argc, char **argv, char **result)
 {
-  size_t len = strcspn (argv[1], "@");
-  char *s;
-
-  s = malloc (len + 1);
+  char *s = strndup (argv[1], strcspn (argv[1], "@"));
   if (!s)
     return MU_WRDSE_NOSPACE;
-  memcpy (s, argv[1], len);
-  s[len] = 0;
-
   *result = s;
   return MU_WRDSE_OK;
 }
@@ -115,6 +109,42 @@ exp_domainpart (int argc, char **argv, char **result)
 
   return MU_WRDSE_OK;
 }
+
+static int
+exp_detail (int argc, char **argv, char **result)
+{
+  char *s = argv[1];
+  size_t n;
+
+  n = strcspn (s, "@+");
+  s += n;
+  if (s[0] == 0)
+    n = 0;
+  else
+    {
+      s++;
+      n = strcspn (s, "@");
+    }
+  s = strndup (s, n);
+  if (!s)
+    return MU_WRDSE_NOSPACE;
+
+  *result = s;
+
+  return MU_WRDSE_OK;
+}
+
+static int
+exp_localuser (int argc, char **argv, char **result)
+{
+  size_t n = strcspn (argv[1], "@+");
+  char *s;
+  s = strndup (argv[1], n);
+  if (!s)
+    return MU_WRDSE_NOSPACE;
+  *result = s;
+  return MU_WRDSE_OK;
+}
 
 static int
 exp_shell (char **ret, char const *str, size_t len, void *closure)
@@ -192,6 +222,8 @@ struct exp_command
 static struct exp_command exp_command_tab[] = {
   { "localpart", 2, 2, exp_localpart },
   { "domainpart", 2, 2, exp_domainpart },
+  { "localuser", 2, 2, exp_localuser },
+  { "detail", 2, 2, exp_detail },
   { NULL }
 };
 
