@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2016-2019 Free Software Foundation, Inc.
+   Copyright (C) 2016-2025 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -197,6 +197,7 @@ struct value_handler value_handler[] = {
   [mu_c_long]   = { v_long_format, v_long_compare },
   [mu_c_ulong]  = { v_ulong_format, v_ulong_compare },
   [mu_c_size]   = { v_size_format, v_size_compare },
+  [mu_c_hsize]  = { v_size_format, v_size_compare },
 #if 0
     mu_c_time,
 #endif
@@ -244,7 +245,6 @@ struct testdata tests[] = {
   { mu_c_short,  "115",             0, { .v_short = 115 } },
   { mu_c_short,  "-400",            0, { .v_short = -400 } },
   { mu_c_short,  "1a",              EINVAL,  },
-
   { mu_c_ushort, "110",             0, { .v_ushort = 110 } },
   { mu_c_ushort, "-110",            ERANGE  },
 
@@ -258,6 +258,19 @@ struct testdata tests[] = {
 
   { mu_c_ulong,  "10568",           0, { .v_ulong = 10568 } },
   
+  { mu_c_size,   "10568",           0, { .v_size = 10568 } },
+
+  { mu_c_hsize,  "0",               0, { .v_size = 0 } },
+  { mu_c_hsize,  "10",              0, { .v_size = 10 } },
+  { mu_c_hsize,  "10K",             0, { .v_size = 10240 } },
+  { mu_c_hsize,  " 10 M  ",         0, { .v_size = 10485760 } },
+  { mu_c_hsize,  "10s",             MU_ERR_PARSE },
+  { mu_c_hsize,  "-1",              MU_ERR_PARSE },
+  { mu_c_hsize,  "",                MU_ERR_PARSE },
+  { mu_c_hsize,  "   ",             MU_ERR_PARSE },
+  { mu_c_hsize,  " 1 M b  ",        MU_ERR_PARSE },
+  
+  
   { mu_c_bool,   "true",            0, { .v_int = 1 } },
   { mu_c_bool,   "false",           0, { .v_int = 0 } },
 
@@ -266,6 +279,11 @@ struct testdata tests[] = {
 	.len = 4,
 	.address = { 127, 0, 0, 0 },
 	.netmask = { 255 } } } },
+  { mu_c_cidr,   "127.10.4.15/8",     0, { .v_cidr = {
+	.family = 2,
+	.len = 4,
+	.address = { 127, 0, 0, 0 },
+	.netmask = { 255 } } } },
 #ifdef MAILUTILS_IPV6  
   { mu_c_cidr,   "fe80::4a5b:39ff:fe09:97f0/64", 0,  { .v_cidr = {
 	.family = 10,
@@ -289,7 +307,7 @@ print_test_id (int i, FILE *fp)
 void
 usage (int code, FILE *fp, char const *argv0)
 {
-  fprintf (fp, "usage: %s [-v]", argv0);
+  fprintf (fp, "usage: %s [-v]\n", argv0);
   exit (code);
 }
 
@@ -341,6 +359,12 @@ main (int argc, char **argv)
 	      ++failures;
 	    }
 	}
+      else if (tests[i].err)
+	{
+	  print_test_id (i, stderr);
+	  fprintf (stderr, "FAIL: unexpected success\n");
+	  ++failures;
+	}
       else if (valcmp (tests[i].type, &tests[i].val, &val))
 	{
 	  fprintf (stderr, "%d: FAIL: %s value differ: ",
