@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2003-2021 Free Software Foundation, Inc.
+   Copyright (C) 2003-2025 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -130,11 +130,12 @@ mu_tls_cfg_init (void)
 {
   struct mu_cfg_section *section;
 
-  if (mu_create_canned_section ("tls", &section))
+  if (mu_create_canned_section_ext ("tls", DEFAULT_TEXT_DOMAIN, &section))
     abort ();
   section->docstring = N_("Configure TLS");
   section->label = NULL;
-  mu_cfg_section_add_params (section, tls_canned_param);
+  mu_cfg_section_add_params_ext (section, tls_canned_param,
+				 DEFAULT_TEXT_DOMAIN);
 }
 
 struct mu_auth_module mu_auth_tls_module = {
