@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2012-2022 Free Software Foundation, Inc.
+   Copyright (C) 2012-2025 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
@@ -210,7 +210,7 @@ index_checker (const char *name, mu_list_t tags, mu_list_t args)
 		        2. locus should be included in t
 	      */
 	      mu_sv_compile_error (&mu_sieve_locus, 
-			      _("index specified twice in call to `%s'"),
+				   _("index specified twice in call to '%s'"),
 				   name);
 	      err = 1;
 	      break;
