@@ -98,7 +98,8 @@ moderator_filter_message (mu_sieve_machine_t mach,
       
       rc = mu_sieve_compile (newmach, arg);
       if (rc)
-	mu_sieve_error (mach, _("cannot compile source `%s'"), arg);
+	mu_sieve_error (mach, _("cannot compile source %s"),
+			mu_quotename (arg));
     }
   else if (mu_sieve_get_tag (mach, "program", SVT_STRING, &arg))
     {
@@ -151,7 +152,7 @@ copy_header (mu_sieve_machine_t mach,
   
   if ((rc = mu_header_sget_value (from_hdr, from, &value)))
     {
-      mu_sieve_error (mach, _("cannot get `%s:' header: %s"),
+      mu_sieve_error (mach, _("cannot get '%s:' header: %s"),
 		      from, mu_strerror (rc));
       return rc;
     }
