@@ -58,7 +58,7 @@ _mu_folder_preauth_callback (void *data, int code, size_t sdat, void *pdat)
   /*  mu_folder_t folder = data;*/
   const char *text = pdat;
   mu_debug (MU_DEBCAT_FOLDER, MU_DEBUG_TRACE1,
-	    (_("IMAP server opened in preauth mode: %s"), text));
+	    (_("IMAP session opened in preauth mode: %s"), text));
 }
 
 static void
