@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2019 Free Software Foundation, Inc.
+   Copyright (C) 1999-2025 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -149,7 +149,7 @@ hdr_text (struct header_call_args *args, void *data)
 static char *
 hdr_cur (struct header_call_args *args, void *data)
 {
-  if (is_current_message (args->mspec->msg_part[0]))
+  if (is_current_message (msgset_msgno (args->mspec)))
     return (char*) data;
   return " ";
 }
@@ -298,11 +298,9 @@ static char *
 hdr_lines (struct header_call_args *args, void *data)
 {
   size_t m_lines;
-  char buf[UINTMAX_STRSIZE_BOUND];
 
-  mu_message_lines (args->msg, &m_lines);
-  
-  return header_buf_string (args, umaxtostr (m_lines, buf));
+  mu_message_lines (args->msg, &m_lines);  
+  return header_buf_string (args, mu_umaxtostr (m_lines));
 }
 
 /* %L */
@@ -310,13 +308,12 @@ static char *
 hdr_quick_lines (struct header_call_args *args, void *data)
 {
   size_t m_lines;
-  char buf[UINTMAX_STRSIZE_BOUND];
   int rc;
   const char *p;
   
   rc = mu_message_quick_lines (args->msg, &m_lines);
   if (rc == 0)
-    p = umaxtostr (m_lines, buf);
+    p = mu_umaxtostr (m_lines);
   else
     p = "NA";
   return header_buf_string (args, p);
@@ -326,8 +323,7 @@ hdr_quick_lines (struct header_call_args *args, void *data)
 static char *
 hdr_number (struct header_call_args *args, void *data)
 {
-  char buf[UINTMAX_STRSIZE_BOUND];
-  return header_buf_string (args, umaxtostr (args->mspec->msg_part[0], buf));
+  return header_buf_string (args, mu_umaxtostr (msgset_msgno (args->mspec)));
 }
 
 /* %o */
@@ -335,10 +331,8 @@ static char *
 hdr_size (struct header_call_args *args, void *data)
 {
   size_t m_size;
-  char buf[UINTMAX_STRSIZE_BOUND];
-  mu_message_size (args->msg, &m_size);
-  
-  return header_buf_string (args, umaxtostr (m_size, buf));
+  mu_message_size (args->msg, &m_size);  
+  return header_buf_string (args, mu_umaxtostr (m_size));
 }
 
 /* %s */
