@@ -234,7 +234,7 @@ ml_command_completion (char *cmd, int start, int end)
 
   if (mu_wordsplit_len (p, end, &ws, MU_WRDSF_DEFFLAGS))
     {
-      mu_error (_("mu_wordsplit_len failed: %s"),
+      mu_error (_("%s failed: %s"), "mu_wordsplit_len",
 		mu_wordsplit_strerror (&ws));
       return NULL;
     }
