@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2003-2019 Free Software Foundation, Inc.
+   Copyright (C) 2003-2025 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -214,17 +214,17 @@ check_exit_status (const char *progname, int status)
     {
       if (WEXITSTATUS (status))
 	{
-	  mu_error (_("command `%s' exited with status %d"),
-		    progname, WEXITSTATUS(status));
+	  mu_error (_("command %s exited with status %d"),
+		    mu_quotename (progname), WEXITSTATUS(status));
 	  return 1;
 	}
       return 0;
     }
   else if (WIFSIGNALED (status))
-    mu_error (_("command `%s' terminated on signal %d"),
-	      progname, WTERMSIG (status));
+    mu_error (_("command %s terminated on signal %d"),
+	      mu_quotename (progname), WTERMSIG (status));
   else
-    mu_error (_("command `%s' terminated abnormally"), progname);
+    mu_error (_("command %s terminated abnormally"), mu_quotename (progname));
   return 1;
 }
 
@@ -347,7 +347,7 @@ _whatnow (struct mh_whatnow_env *wh, struct action_tab *tab)
       rc = mu_wordsplit (line, &ws, wsflags);
       if (rc)
 	{
-	  mu_error (_("cannot split line `%s': %s"), line,
+	  mu_error (_("cannot split line %s: %s"), mu_quotename (line),
 		    mu_wordsplit_strerror (&ws));
 	  status = 1;
 	  break;
@@ -432,7 +432,7 @@ edit (struct mh_whatnow_env *wh, int argc, char **argv, int *whs)
 			| MU_WRDSF_ENV 
                         | MU_WRDSF_NOCMD))
 	{
-	  mu_error (_("cannot split line `%s': %s"), ed,
+	  mu_error (_("cannot split line %s: %s"), mu_quotename (ed),
 		    mu_wordsplit_strerror (&ws));
 	  rc = MU_ERR_FAILURE;
 	}
@@ -501,14 +501,15 @@ quit (struct mh_whatnow_env *wh, int argc, char **argv, int *status)
 	unlink (wh->draftfile);
       else
 	{
-	  mu_printf (_("draft left on \"%s\"."), wh->draftfile);
+	  mu_printf (_("draft left on %s."), mu_quotename (wh->draftfile));
 	  if (strcmp (wh->file, wh->draftfile))
 	    {
 	      int rc;
 	      rc = mu_rename_file (wh->file, wh->draftfile, MU_COPY_OVERWRITE);
 	      if (rc)
-		mu_error (_("can't rename %s to %s: %s"),
-			  wh->file, wh->draftfile, mu_strerror (rc));
+		mu_error (_("cannot rename %s to %s: %s"),
+			  mu_quotename_n (0, wh->file),
+			  mu_quotename_n (1, wh->draftfile), mu_strerror (rc));
 	    }
 	}
     }
@@ -688,7 +689,6 @@ mh_whatnowproc (struct mh_whatnow_env *wh, int initial_edit, const char *prog)
   if (pid == 0)
     {
       struct mu_wordsplit ws;
-      int i;
       
       if (mu_wordsplit (prog, &ws,
 			MU_WRDSF_DEFFLAGS & ~MU_WRDSF_CESCAPES))
@@ -700,8 +700,7 @@ mh_whatnowproc (struct mh_whatnow_env *wh, int initial_edit, const char *prog)
       
       set_default_editor (wh);
       mh_whatnow_env_to_environ (wh);
-      for (i = mu_getmaxfd (); i > 2; i--)
-	close (i);
+      mu_close_fds (3);
       execvp (ws.ws_wordv[0], ws.ws_wordv);
       mu_diag_funcall (MU_DIAG_ERROR, "execvp", prog, errno);
       _exit (127);
@@ -797,7 +796,7 @@ mh_usedraft (const char *filename)
   
   memset (&wh, 0, sizeof (wh));
   wh.file = mu_strdup (filename);
-  mu_asprintf (&wh.prompt, _("Use \"%s\"?"), filename);
+  mu_asprintf (&wh.prompt, _("Use %s?"), mu_quotename (filename));
   rc = _whatnow (&wh, usedraft_tab);
   free (wh.prompt);
   free (wh.file);
