@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2003-2024 Free Software Foundation, Inc.
+   Copyright (C) 2003-2025 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -111,7 +111,7 @@ split_args (const char *argstr, size_t len, size_t *pargc, char ***pargv)
 			(MU_WRDSF_DEFFLAGS & ~MU_WRDSF_QUOTE) |
 			MU_WRDSF_DELIM | MU_WRDSF_WS))
     {
-      mu_error (_("cannot split line `%s': %s"), argstr,
+      mu_error (_("cannot split line %s: %s"), mu_quotename (argstr),
 		mu_wordsplit_strerror (&ws));
       *pargc = 0;
       *pargv = NULL;
@@ -322,7 +322,7 @@ msg_part_print (msg_part_t p, int max_width)
 	  printf (".");
 	  width++;
 	}
-      width += printf ("%s", mu_umaxtostr (0, p->part[i]));
+      width += printf ("%s", mu_umaxtostr (p->part[i]));
     }
   for (; width < max_width; width++)
     putchar (' ');
@@ -339,7 +339,7 @@ msg_part_format (msg_part_t p)
     {
       if (i > 1)
 	width++;
-      width += strlen (mu_umaxtostr (0, p->part[i]));
+      width += strlen (mu_umaxtostr (p->part[i]));
     }
 
   str = s = mu_alloc (width + 1);
@@ -347,7 +347,7 @@ msg_part_format (msg_part_t p)
     {
       if (i > 1)
 	*s++ = '.';
-      s += sprintf (s, "%s", mu_umaxtostr (0, p->part[i]));
+      s += sprintf (s, "%s", mu_umaxtostr (p->part[i]));
     }
   *s = 0;
   return str;
@@ -366,7 +366,7 @@ msg_part_format_pool (mu_opool_t pool, msg_part_t p)
       if (i > 1)
 	mu_opool_append_char (pool, '.');
 
-      buf = mu_umaxtostr (0, p->part[i]);
+      buf = mu_umaxtostr (p->part[i]);
       len = strlen (buf);
       mu_opool_append (pool, buf, len);
     }
@@ -830,10 +830,8 @@ mhn_store_command (mu_message_t msg, msg_part_t part, const char *name,
 	      if (name)
 		mu_opool_appendz (pool, name);
 	      else
-		{
-                  const char *buf = mu_umaxtostr (0, msg_part_subpart (part, 0));
-		  mu_opool_appendz (pool, buf);
-		}
+		mu_opool_appendz (pool, 
+                                  mu_umaxtostr (msg_part_subpart (part, 0)));
 	      break;
 
 	    case 'P':
@@ -1239,7 +1237,7 @@ show_internal (mu_message_t msg, msg_part_t part, char *encoding,
   if ((rc = mu_message_get_body (msg, &body)))
     {
       mu_error (_("%s: cannot get message body: %s"),
-		mu_umaxtostr (0, msg_part_subpart (part, 0)),
+		mu_umaxtostr (msg_part_subpart (part, 0)),
 		mu_strerror (rc));
       return 0;
     }
@@ -1300,7 +1298,8 @@ mhn_run_command (mu_message_t msg, msg_part_t part,
       ws.ws_comment = "#";
       if (mu_wordsplit (cmd, &ws, MU_WRDSF_DEFFLAGS | MU_WRDSF_COMMENT))
 	{
-	  mu_error (_("cannot parse command line `%s': %s"), cmd,
+	  mu_error (_("cannot parse command line %s: %s"),
+		    mu_quotename (cmd),
 		    mu_wordsplit_strerror (&ws));
 	  return ENOSYS;
 	}
@@ -1523,7 +1522,7 @@ store_handler (mu_message_t msg, msg_part_t part, char *type, char *encoding,
   partstr = msg_part_format (part);
   /* Set prefix for diagnostic purposes */
   if (!prefix)
-    prefix = mu_umaxtostr (0, msg_part_subpart (part, 0));
+    prefix = mu_umaxtostr (msg_part_subpart (part, 0));
   out = NULL;
   rc = 0;
   switch (dest)
@@ -1625,13 +1624,14 @@ store_handler (mu_message_t msg, msg_part_t part, char *type, char *encoding,
 	ws.ws_comment = "#";
 	if (mu_wordsplit (name, &ws, MU_WRDSF_DEFFLAGS|MU_WRDSF_COMMENT))
 	  {
-	    mu_error (_("cannot split line `%s': %s"), name,
+	    mu_error (_("cannot split line %s: %s"), mu_quotename (name),
 		      mu_wordsplit_strerror (&ws));
 	    break;
 	  }
 	
 	printf (_("storing msg %s part %s using command (cd %s; %s)\n"),
 		prefix, partstr, hints.mu_prog_workdir, name);
+	fflush (stdout);
 	rc = mu_prog_stream_create (&out,
 				    ws.ws_wordv[0],
 				    ws.ws_wordc, ws.ws_wordv,
@@ -1646,6 +1646,7 @@ store_handler (mu_message_t msg, msg_part_t part, char *type, char *encoding,
     case store_to_stdout:
       printf (_("storing msg %s part %s to stdout\n"),
 	      prefix, partstr);
+      fflush (stdout);
       rc = 0;
       out = mu_strout;
       mu_stream_ref (out);
@@ -1967,7 +1968,7 @@ copy_header_to_stream (mu_message_t msg, mu_stream_t stream)
   mu_stream_unref (str);
   if (rc)
     {
-      mu_error (_("cannot open filter stream: %s"), mu_strerror (rc));
+      mu_diag_funcall (MU_DIAG_ERROR, "mu_filter_create", "HEADER", rc);
       exit (1);
     }
   rc = mu_stream_copy (stream, flt, 0, NULL);
@@ -2768,14 +2769,15 @@ mhn_compose (void)
 
   rc = mu_rename_file (input_file, backup, MU_COPY_OVERWRITE);
   if (rc)
-    mu_error (_("can't rename %s to backup file %s: %s"),
+    mu_error (_("cannot rename %s to backup file %s: %s"),
 	      input_file, backup, mu_strerror (rc));
   else
     {
       rc = mu_rename_file (name, input_file, 0);
       if (rc)
-	mu_error (_("can't rename %s to %s: %s"),
-		  name, input_file, mu_strerror (rc));
+	mu_error (_("cannot rename %s to %s: %s"),
+		  mu_quotename_n (0, name),
+		  mu_quotename_n (1, input_file), mu_strerror (rc));
     }
 
   free (name);
