@@ -1751,7 +1751,7 @@ set_cflags (char const *str)
 	  break;
 
 	default:
-	  mu_error (_("Invalid regular expression flag: %c"), *str);
+	  mu_error (_("invalid regular expression flag: %c"), *str);
 	  exit (1);
 	}
     }
