@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2003-2021 Free Software Foundation, Inc.
+   Copyright (C) 2003-2025 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -138,13 +138,14 @@ static struct mu_option options[] = {
     mu_c_int, &width },
   MU_OPTION_GROUP (N_("Setting sort keys:")),
   { "datefield",     0, N_("STRING"), MU_OPTION_DEFAULT,
-    N_("sort on the date field (default `Date:')"),
+    N_("sort on the date field (default 'Date')"),
     mu_c_string, NULL, add_datefield },
   { "nodatefield",   0, NULL,       MU_OPTION_DEFAULT,
     N_("don't sort on the date field"),
     mu_c_string, NULL, rem_datefield },
   { "limit",         0, N_("DAYS"), MU_OPTION_DEFAULT,
-    N_("consider two datefields equal if their difference lies within the given nuber of DAYS."),
+    N_("consider two datefields equal if their difference falls within"
+       " the given number of DAYS."),
     mu_c_int, &limit },
   { "nolimit",       0,       NULL,       MU_OPTION_DEFAULT,
     N_("undo the effect of the last -limit option"),
@@ -212,9 +213,10 @@ addop (char const *field, compfun comp)
   
   if (!oplist)
     {
-      if (mu_list_create (&oplist))
+      int rc;
+      if ((rc = mu_list_create (&oplist)) != 0)
 	{
-	  mu_error (_("can't create operation list"));
+	  mu_diag_funcall (MU_DIAG_ERROR, "mu_list_create", NULL, rc);
 	  exit (1);
 	}
       mu_list_set_destroy_item (oplist, mu_list_free_item);
@@ -387,8 +389,8 @@ comp0 (size_t na, size_t nb)
   if (verbose > 1)
     fprintf (stderr,
 	     _("comparing messages %s and %s: "),
-	     mu_umaxtostr (0, na),
-	     mu_umaxtostr (1, nb));
+	     mu_umaxtostr_n (0, na),
+	     mu_umaxtostr_n (1, nb));
   return compare_messages (a, b, na, nb);
 }
 
@@ -451,8 +453,8 @@ swap_message (size_t a, size_t b)
   char *path_a, *path_b;
   char *tmp;
   
-  path_a = mh_safe_make_file_name (mbox_path, mu_umaxtostr (0, a));
-  path_b = mh_safe_make_file_name (mbox_path, mu_umaxtostr (1, b));
+  path_a = mh_safe_make_file_name (mbox_path, mu_umaxtostr (a));
+  path_b = mh_safe_make_file_name (mbox_path, mu_umaxtostr (b));
   tmp = mu_tempname (mbox_path);
   rename (path_a, tmp);
   unlink (path_a);
@@ -460,6 +462,8 @@ swap_message (size_t a, size_t b)
   unlink (path_b);
   rename (tmp, path_b);
   free (tmp);
+  free (path_a);
+  free (path_b);
 }
 
 void
@@ -479,7 +483,7 @@ transpose(size_t i, size_t n)
   
 static int got_signal;
 
-RETSIGTYPE
+void
 sighandler (int sig)
 {
   got_signal = 1;
@@ -533,8 +537,8 @@ sort (void)
 	      if (verbose)
 		{
 		  fprintf (stderr, "{%s, %s}",
-			   mu_umaxtostr (0, old_num),
-			   mu_umaxtostr (1, new_num));
+			   mu_umaxtostr_n (0, old_num),
+			   mu_umaxtostr_n (1, new_num));
 		}
 	      if (old_num == current_num)
 		{
@@ -557,9 +561,9 @@ sort (void)
     }
   if (action == ACTION_REORDER)
     {
-      mu_mailbox_uidvalidity_reset (mbox);
       mu_mailbox_close (mbox);
       mu_mailbox_open (mbox, MU_STREAM_RDWR);
+      mu_mailbox_uidvalidity_reset (mbox);
       mh_mailbox_set_cur (mbox, current_num);
     }
 }
