@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2021 Free Software Foundation, Inc.
+   Copyright (C) 1999-2025 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -55,7 +55,7 @@ set_action (struct mu_parseopt *po, struct mu_option *opt, char const *arg)
   if (action != -1)
     {
       mu_parseopt_error (po,
-			 _("You may not specify more than one `-aldp' option"));
+			 _("You may not specify more than one '-aldp' option"));
       exit (po->po_exit_error);
     }
   
@@ -485,8 +485,8 @@ action_create (void)
       rc = mu_file_stream_create (&in, input_name, MU_STREAM_READ);
       if (rc)
 	{
-	  mu_error (_("cannot open file %s: %s"),
-		    input_name, mu_strerror (rc));
+	  mu_diag_funcall (MU_DIAG_ERROR, "mu_file_stream_create",
+			   input_name, rc);
 	  return 1;
 	}
     }
